"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenericClient = void 0;
const axios_1 = __importDefault(require("axios"));
const api_1 = require("../api");
const error_1 = require("../model/error");
const queryParams_1 = require("../model/queryParams");
class GenericClient {
    constructor(config) {
        this.config = config;
        this.httpClient = axios_1.default.create({
            validateStatus: () => true,
        });
    }
    create(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath;
            const res = yield this.httpClient.post(url, api_1.ObjectSerializer.serialize(data, this.config.writeTypeName), {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = api_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw error_1.CoreApiError.fromHttpResponse(res);
            }
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const queryParams = (0, queryParams_1.serializeGetQueryParams)(query);
            const url = this.config.basePath +
                this.config.endpointPath +
                "/" +
                id +
                "?" +
                queryParams;
            const res = yield this.httpClient.get(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = api_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw error_1.CoreApiError.fromHttpResponse(res);
            }
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const queryParams = (0, queryParams_1.serializeFindQueryParams)(findParams);
            const url = this.config.basePath + this.config.endpointPath + "?" + queryParams;
            const res = yield this.httpClient.get(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = api_1.ObjectSerializer.deserialize(res.data, this.config.multipleResponseTypeName);
                return result;
            }
            else {
                throw error_1.CoreApiError.fromHttpResponse(res);
            }
        });
    }
    patch(id, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath + "/" + id;
            const res = yield this.httpClient.patch(url, JSON.stringify(api_1.ObjectSerializer.serialize(data, this.config.patchTypeName)), {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = api_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw error_1.CoreApiError.fromHttpResponse(res);
            }
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.config.basePath + this.config.endpointPath + "/" + id;
            const res = yield this.httpClient.delete(url, {
                headers: yield this.config.auth.getHeaders(),
            });
            if (res.status === 200) {
                const result = api_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
                return result;
            }
            else {
                throw error_1.CoreApiError.fromHttpResponse(res);
            }
        });
    }
}
exports.GenericClient = GenericClient;
