"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("./helpers");
const api_1 = require("../api");
const chai_1 = require("chai");
describe("Test random crud operations", () => __awaiter(void 0, void 0, void 0, function* () {
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        yield helpers_1.client.refreshTestData();
    }));
    it("Find person", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield helpers_1.client.persons.find();
        chai_1.assert.instanceOf(result, api_1.WrappedWithMetaArrayPerson);
        chai_1.assert.isAbove(result.meta.total, 0);
    }));
    it("Get Relation", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield helpers_1.client.relations.get(helpers_1.relationUid);
        chai_1.assert.instanceOf(result, api_1.WrappedRelation);
    }));
    it("Patch and create consent", () => __awaiter(void 0, void 0, void 0, function* () {
        yield helpers_1.client.consents.patch(helpers_1.person1ActiveConsentUid, {
            validTo: new Date(),
        });
        const result = yield helpers_1.client.consents.create({
            orgUid: helpers_1.org1Uid,
            personUid: helpers_1.person1Uid,
            purpose: api_1.ConsentPurpose.DataSharing,
            validFrom: new Date(),
        });
        chai_1.assert.instanceOf(result, api_1.WrappedConsent);
    }));
    it("Remove affiliation", () => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield helpers_1.client.affiliations.remove(helpers_1.affiliationUid);
        chai_1.assert.instanceOf(res, api_1.WrappedAffiliation);
        try {
            yield helpers_1.client.affiliations.get(helpers_1.affiliationUid);
            chai_1.assert.fail("Should not find affiliation");
        }
        catch (err) {
            if (!(0, api_1.isCoreApiError)(err))
                throw Error("Invalid error type");
            chai_1.assert.equal(err.details.code, api_1.ErrorCode.NotFound);
        }
    }));
}));
