var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from "axios";
import { Environment, defaultEnvironmentConfig, } from "../configuration/environments";
import { Scope } from "../model/scopes";
import { AffiliationsClient } from "./affiliationsClient";
import { Auth } from "./auth";
import { ConsentsClient } from "./consentsClient";
import { CountriesClient } from "./countriesClient";
import { OrgsClient } from "./orgsClient";
import { PersonsClient } from "./personsClient";
import { RelationsClient } from "./relationsClient";
import { RolesClient } from "./rolesClient";
import { RoleAssignmentsClient } from "./roleAssignmentsClient";
export class CoreApiClient {
    get affiliations() {
        return this._affiliations;
    }
    get consents() {
        return this._consents;
    }
    get countries() {
        return this._countries;
    }
    get orgs() {
        return this._orgs;
    }
    get persons() {
        return this._persons;
    }
    get relations() {
        return this._relations;
    }
    get roles() {
        return this._roles;
    }
    get roleAssignments() {
        return this._roleAssignments;
    }
    constructor(config) {
        var _a, _b, _c, _d, _e;
        const env = config.environment;
        this.auth = new Auth({
            audience: (_a = config.customOauthAudience) !== null && _a !== void 0 ? _a : defaultEnvironmentConfig[env].oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: (_b = config.scopes) !== null && _b !== void 0 ? _b : (env === Environment.Emulator ? Object.values(Scope) : undefined),
            tokenUrl: (_c = config.customOauthTokenUrl) !== null && _c !== void 0 ? _c : defaultEnvironmentConfig[env].tokenUrl,
            customOptions: (_d = config.customOptions) !== null && _d !== void 0 ? _d : (env === Environment.Emulator ? { orgs: "-" } : undefined),
        });
        this.basePath =
            (_e = config.customApiBaseUrl) !== null && _e !== void 0 ? _e : defaultEnvironmentConfig[env].apiBaseUrl;
        this._affiliations = new AffiliationsClient(this.basePath, this.auth);
        this._consents = new ConsentsClient(this.basePath, this.auth);
        this._countries = new CountriesClient(this.basePath, this.auth);
        this._orgs = new OrgsClient(this.basePath, this.auth);
        this._persons = new PersonsClient(this.basePath, this.auth);
        this._relations = new RelationsClient(this.basePath, this.auth);
        this._roles = new RolesClient(this.basePath, this.auth);
        this._roleAssignments = new RoleAssignmentsClient(this.basePath, this.auth);
    }
    refreshTestData() {
        return __awaiter(this, void 0, void 0, function* () {
            return axios.post(this.basePath + "/refresh-data");
        });
    }
}
