var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { affiliationUid, client, getDefaultConfig } from "./helpers";
import { CoreApiClient, ErrorCode, isCoreApiError } from "../api";
import { CoreApiError } from "../model/error";
import { Scope } from "../model/scopes";
describe("Errors", () => __awaiter(void 0, void 0, void 0, function* () {
    it("Test error helpers", () => {
        function throwFunction() {
            throw new CoreApiError({
                error: {
                    code: ErrorCode.InvalidBody,
                    message: "test message",
                },
            });
        }
        try {
            throwFunction();
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw "Invalid error type";
            assert.equal(err.details.code, ErrorCode.InvalidBody);
            assert.equal(err.message, "test message");
        }
    });
    it("Invalid scope error", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const config = getDefaultConfig();
            config.scopes = [Scope.PersonsRead];
            const clientWithOutScope = new CoreApiClient(config);
            yield clientWithOutScope.affiliations.get(affiliationUid);
            assert.fail("Was able to remove with an invalid scope");
        }
        catch (err) {
            if (!(err instanceof CoreApiError))
                assert.fail("Invalid error type");
            assert.equal(err.details.code, ErrorCode.MissingScopes);
            assert.equal(err.message, "not allowed: missing scope: need any of persons.affiliations#read");
        }
    }));
    it("Non existing error", () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const fakeUid = "657a66ca-9cd0-4b61-9476-697016e26fbc";
            yield client.affiliations.get(fakeUid);
            assert.fail("Was able to remove with a non existing affiliation");
        }
        catch (err) {
            if (!(err instanceof CoreApiError))
                assert.fail("Invalid error type");
            assert.equal(err.details.code, ErrorCode.NotFound);
        }
    }));
}));
